import tkinter as tk
import tkinter.filedialog as fd
import pandas as pd
import numpy as np
import scipy.stats as ss
import matplotlib.pyplot as plt

def askinfilename(msg = None, types = [('', '*.*')]):
    """
            入力用ファイル名の設定用ダイアログウィンドウ
    """
    rt = tk.Tk()
    rt.withdraw()
    flnm = fd.askopenfilename(title = msg, filetypes = types)
    rt.destroy()
    return flnm

def askoutfilename(msg = None, types = [('', '*.*')], deftype = '.txt'):
    """
            出力用ファイル名の設定用ダイアログウィンドウ
    """
    rt = tk.Tk()
    rt.withdraw()
    flnm = fd.asksaveasfilename(title = msg, filetypes = types,
                                           defaultextension = deftype)
    rt.destroy()
    return flnm


finnm = askinfilename('入力データExcelファイル', types = [('Excel(*.xlsx)', '*.xlsx')])
foutnm = askoutfilename(msg = '出力用テキスト', types = [('Text (*.txt)', '*.txt')],
                       deftype = '.txt')
fpltnm = askoutfilename(msg = 'グラフ保存ファイル', types = [('画像(*,png)', '*.png')],
                        deftype = '.png')

fout = open(foutnm, 'w')
fout.write('\n入力データファイル：{}\n'.format(finnm))
#   ExcelデータファイルからExcelFile型のオブジェクトの生成
xlsx_fl = pd.ExcelFile(finnm)
#   ExcelFile型のオブジェクトからDataFrame型のオブジェクトの生成
data_xlsx = pd.read_excel(xlsx_fl,  header = None)
#   DataFrame型のオブジェクトからndarray型のオブジェクトの生成
data = data_xlsx.values
print('\n', data)
var_name = data[0,1]                                #   変量名
X = data[1:, 1]                                     #   データ値、numpy.ndarray

print(X)
fout.write('\n変量: {}\n'.format(var_name))
fout.write('\nデータ値:\n{}\n'.format(X))

Y = sorted(X)
print(Y)
fout.write('\n順序統計量:\n')
nl = 0
for v in Y:
    fout.write('  {}'.format(v))
    nl += 1
    if nl >= 10:
        nl = 0
        fout.write('\n')


Pctl = np.array([v+1 for v in range(len(Y))]) * 100 / len(Y)

#       日本語表記の設定
plt.rcParams['font.family'] = ['Yu Gothic', 'Noto Sans CJK JP', 'Hiragino Maru Gothic Pro']

plt.title('百分位数', fontsize = 20)
plt.plot(Pctl, Y)
plt.xlabel('パーセンタイル順位', fontsize = 12)
plt.ylabel(var_name, fontsize = 14)
plt.savefig(fpltnm)
plt.show()

X_min = min(X)
X_max = max(X)
print(X_min)
fout.write('\n最小値 = {0:.3f}\n'.format(X_min))
print(X_max)
fout.write('\n最大値 = {0:.3f}\n'.format(X_max))

Q1, Med, Q3 = np.percentile(X, [25, 50, 75])
print(Q1, Med, Q3)
fout.write('\n第１四分位数 = {0:.3f}\n'.format(Q1))
fout.write('\n中央値       = {0:.3f}\n'.format(Med))
fout.write('\n第３四分位数 = {0:.3f}\n'.format(Q3))

fout.close()
print('\n出力テキストファイル:\n{}\n'.format(foutnm))
